.ai
.github
.idea
AGENTS.md
Agents
CHANGELOG.md
CLAUDE.md
ClicShoppingAdmin
Core
HELP.md
README.md
SECURITY.md
_config.yml
_htaccess
clear_all_caches_complete.php
composer.json
composer.lock
docs
error_documents
ext
favicon.ico
favicon.png
images
index.php
install
license.txt
manifest.php
migrate_passwords_http.php
offline.php
pwabuilder-sw.js
redirect.php
robots.txt
sources
sql_upgrade