<?php
$ini = <<<EOD
dir_root = "[[softpath]]/ClicShoppingAdmin/"
http_server = "[[protocol]]://[[domhost]]"
http_path = "[[relativeurl]]/ClicShoppingAdmin/"
http_images_path = "images/"
http_cookie_domain = ""
http_cookie_path = "[[relativeurl]]/ClicShoppingAdmin/"
dir_core = "Core"
EOD;
