<?php
$ini = <<<EOD
dir_root = "[[softpath]]/"
http_server = "[[protocol]]://[[domhost]]"
http_path = "[[relativeurl]]/"
http_images_path = "images/"
http_cookie_domain = ""
http_cookie_path = "[[relativeurl]]/"
dir_core = "Core"
EOD;
